@@ -1,6 +1,9 @@
 import os
 from environs import Env
 from app.basedir import BASE_DIR
+import sentry_sdk
+from sentry_sdk.integrations.django import DjangoIntegration
+
 
 env = Env()
 env.read_env(os.path.join(BASE_DIR, '.env'), recurse=True)
@@ -22,6 +25,7 @@ SITE_ID = 1
 # Application definition
 
 INSTALLED_APPS = [
+    'tabbed_admin',
     'modeltranslation',
     'polymorphic_tree',
     'polymorphic',
@@ -178,6 +182,9 @@ COMMON_CONTEXT = 'garpix_page.contexts.default.context'
 
 # menu
 
+MENU_ICON_ALLOWED_TYPES = ['bmp', 'svg', 'jpg', 'png', 'jpeg']
+MENU_ICON_MAX_SIZE = 1024 * 1024 * 1
+
 MENU_TYPE_HEADER_MENU = 'header_menu'
 MENU_TYPE_FOOTER_MENU = 'footer_menu'
 
@@ -295,5 +302,13 @@ if ENABLE_GARPIX_AUTH:
 GARPIX_PAGE_ADMIN_LIST_PER_PAGE = 25
 GARPIX_PAGE_GLOBAL_CONTEXT = 'garpixcms.contexts.global_context.global_context'
 
+# sentry
+SENTRY_DSN_STRING = env('SENTRY_DSN_STRING', '')
+if SENTRY_DSN_STRING != '':
+    sentry_sdk.init(
+        dsn=SENTRY_DSN_STRING,
+        integrations=[DjangoIntegration()]
+    )
+
 if DEBUG:
     CORS_ALLOW_ALL_ORIGINS = True
