@@ -8,7 +8,7 @@ with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
 
 setup(
     name='garpixcms',
-    version='2.9.0',
+    version='3.5.0',
     description='',
     long_description=long_description,
     url='https://github.com/garpixcms/garpixcms',
@@ -31,12 +31,12 @@ setup(
     install_requires=[
         'Django == 3.1',
         'garpix_utils >= 1.3.0',
-        'garpix_page == 2.9.0',
-        'garpix_menu == 1.2.0',
-        'garpix_qa == 1.2.0',
-        'garpix_auth == 2.0.2',
-        'garpix_notify == 4.1.0',
-        'garpix_package == 2.0.0',
+        'garpix_page == 2.13.0',
+        'garpix_menu == 1.7.0',
+        'garpix_qa == 1.6.0',
+        'garpix_auth == 2.3.0',
+        'garpix_notify == 5.3.0',
+        'garpix_package == 2.0.1',
         'psycopg2-binary >= 2.8.6',
         'uwsgi >= 2.0.19.1',
         'environs >= 9.3.2',
@@ -44,5 +44,8 @@ setup(
         'djangorestframework >= 3.12.4',
         'django-cors-headers == 3.7.0',
         'drf-spectacular >= 0.18.2',
+        'sentry-sdk >= 1.5.2',
+        'pre-commit >= 2.17.0',
+        'django-tabbed-admin >= 1.0.4',
     ],
 )
